package
Version:
v0.0.0-...-ef3af43
Opens a new window with list of versions in this module.
Published: Apr 4, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package pid writes the current PID to a file, ensuring that the file
doesn't exist or doesn't contain a PID for a running process.
type Component interface{}
Component is the component type.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.