remoteimpl

package module
v0.80.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 10, 2026 License: Apache-2.0 Imports: 39 Imported by: 1

Documentation

Overview

Package remoteimpl implements a remote Tagger.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Options

type Options struct {
	Target   string
	Disabled bool
}

Options contains the options needed to configure the remote tagger.

type Provides

type Provides struct {
	compdef.Out

	Comp          tagger.Component
	Endpoint      api.AgentEndpointProvider
	FlareProvider flaretypes.Provider
}

Provides contains the fields provided by the remote tagger constructor.

func NewComponent

func NewComponent(req Requires) (Provides, error)

NewComponent returns a remote tagger

type Requires

type Requires struct {
	compdef.In

	Lc        compdef.Lifecycle
	Config    config.Component
	Log       log.Component
	Params    tagger.RemoteParams
	Telemetry coretelemetry.Component
	IPC       ipc.Component
}

Requires defines the dependencies for the remote tagger.

Jump to