telemetry

package module
v0.78.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 6, 2026 License: Apache-2.0 Imports: 2 Imported by: 2

Documentation

Overview

Package telemetry defines the telemetry for the Tagger component.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CardinalityTelemetry

type CardinalityTelemetry struct {
	EmptyEntityID telemetry.SimpleCounter
	EmptyTags     telemetry.SimpleCounter
	Success       telemetry.SimpleCounter
}

CardinalityTelemetry contains the telemetry for a specific cardinality level.

type Store

type Store struct {
	// / StoredEntities tracks how many entities are stored in the tagger.
	StoredEntities telemetry.Gauge
	// UpdatedEntities tracks the number of updates to tagger entities.
	UpdatedEntities telemetry.Counter

	// PrunedEntities tracks the number of pruned tagger entities.
	PrunedEntities telemetry.Gauge

	// ClientStreamErrors tracks how many errors were received when streaming
	// tagger events.
	ClientStreamErrors telemetry.Counter

	// Subscribers tracks how many subscribers the tagger has.
	Subscribers telemetry.Gauge
	// Events tracks the number of tagger events being sent out.
	Events telemetry.Counter

	// Sends tracks the number of times the tagger has sent a
	// notification with a group of events.
	Sends telemetry.Counter

	// Receives tracks the number of times the tagger has received a
	// notification with a group of events.
	Receives telemetry.Counter

	// OriginInfoRequests tracks the number of requests to the Tagger
	// to generate a container ID from Origin Info.
	OriginInfoRequests telemetry.Counter

	LowCardinalityQueries          CardinalityTelemetry
	OrchestratorCardinalityQueries CardinalityTelemetry
	HighCardinalityQueries         CardinalityTelemetry
	NoneCardinalityQueries         CardinalityTelemetry
	UnknownCardinalityQueries      CardinalityTelemetry
}

Store contains all the telemetry for the Tagger component.

func NewStore

func NewStore(telemetryComp telemetry.Component) *Store

NewStore returns a new Store.

func (*Store) QueriesByCardinality

func (s *Store) QueriesByCardinality(card types.TagCardinality) *CardinalityTelemetry

QueriesByCardinality returns a set of counters for a given cardinality level.

Jump to