utils

package module
v0.78.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 28, 2026 License: Apache-2.0 Imports: 3 Imported by: 2

Documentation

Overview

Package utils defines several helpers used by the Tagger component.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ComputeTagsHash

func ComputeTagsHash(tags []string) string

ComputeTagsHash returns a hash of the supplied tags.

func ConcatenateStringTags

func ConcatenateStringTags(tags []string, extraTags ...string) []string

ConcatenateStringTags adds string tags to existing tag array

func ConcatenateTags

func ConcatenateTags(slices ...[]string) []string

ConcatenateTags is a fast way to concatenate multiple tag arrays in a single one.

Types

This section is empty.

Jump to