Documentation
¶
Overview ¶
Package orchestratorinterface defines the interface for the orchestrator forwarder component.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Component ¶
type Component interface {
// Get the forwarder instance if it exists.
Get() (defaultforwarder.Forwarder, bool)
}
Component is the component type. The main method of this component is `Get` which returns the forwarder instance only if it enabled.
Click to show internal directories.
Click to hide internal directories.