serverimpl

package
v0.0.0-...-3ec880f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2026 License: Apache-2.0 Imports: 20 Imported by: 0

Documentation

Overview

Package serverimpl implements the netflow server component.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Provider

type Provider struct {
	// contains filtered or unexported fields
}

Provider provides the functionality to populate the status output

func (Provider) HTML

func (p Provider) HTML(_ bool, buffer io.Writer) error

HTML renders the html output

func (Provider) JSON

func (p Provider) JSON(_ bool, stats map[string]interface{}) error

JSON populates the status map

func (Provider) Name

func (Provider) Name() string

Name returns the name

func (Provider) Section

func (Provider) Section() string

Section return the section

func (Provider) Text

func (p Provider) Text(_ bool, buffer io.Writer) error

Text renders the text output

type Provides

type Provides struct {
	compdef.Out

	Comp           server.Component
	StatusProvider status.InformationProvider
}

Provides defines what the netflow server component provides.

func NewComponent

func NewComponent(deps Requires) (Provides, error)

NewComponent configures a netflow server.

type Requires

type Requires struct {
	compdef.In
	Lc            compdef.Lifecycle
	Config        nfconfig.Component
	Logger        log.Component
	Demultiplexer demultiplexer.Component
	Forwarder     forwarder.Component
	Hostname      hostname.Component
	RDNSQuerier   rdnsquerier.Component
}

Requires defines the dependencies for the netflow server component.

type Server

type Server struct {
	Addr string

	FlowAgg *flowaggregator.FlowAggregator
	// contains filtered or unexported fields
}

Server manages netflow listeners.

func (*Server) Start

func (s *Server) Start() error

Start starts the server running

func (*Server) Stop

func (s *Server) Stop()

Stop stops the Server.

Jump to