Documentation
¶
Overview ¶
Package types contains all the types needed by the OpenTelemetry Extension component without the underlying implementation and dependencies.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BuildInfoResponse ¶
type BuildInfoResponse struct {
AgentVersion string `json:"version"`
AgentCommand string `json:"command"`
AgentDesc string `json:"description"`
ExtensionVersion string `json:"extension_version"`
BYOC bool `json:"byoc"`
}
BuildInfoResponse is the response struct for BuildInfo
type ConfigResponse ¶
type ConfigResponse struct {
CustomerConfig string `json:"provided_configuration"`
EnvConfig string `json:"environment_variable_configuration"`
RuntimeOverrideConfig string `json:"runtime_override_configuration"`
RuntimeConfig string `json:"full_configuration"`
}
ConfigResponse is the response struct for Config
type DebugSourceResponse ¶
type DebugSourceResponse struct {
Sources map[string]OTelFlareSource `json:"sources,omitempty"`
}
DebugSourceResponse is the response struct for a map of OTelFlareSource
type OTelFlareSource ¶
type OTelFlareSource struct {
URLs []string `json:"url"`
}
OTelFlareSource is the response struct for flare debug sources
type Response ¶
type Response struct {
BuildInfoResponse
ConfigResponse
DebugSourceResponse
Environment map[string]string `json:"environment,omitempty"`
}
Response is the response struct for API queries
Click to show internal directories.
Click to hide internal directories.