Documentation
¶
Overview ¶
Package ddprofilingextensionimpl defines the OpenTelemetry Extension implementation.
Package ddprofilingextensionimpl defines the OpenTelemetry Profiling implementation ¶
Package ddprofilingextensionimpl defines the OpenTelemetry Extension implementation.
Package ddprofilingextensionimpl defines the OpenTelemetry Profiling implementation
Index ¶
- Variables
- func NewExtension(cfg *Config, info component.BuildInfo, traceAgent traceagent.Component, ...) (ddprofilingextensiondef.Component, error)
- func NewFactory() extension.Factory
- func NewFactoryForAgent(traceAgent traceagent.Component, log corelog.Component) extension.Factory
- type Config
- type ProfilerOptions
Constants ¶
This section is empty.
Variables ¶
var Type = component.MustNewType("ddprofiling")
Type exports the internal metadata type for easy reference
Functions ¶
func NewExtension ¶
func NewExtension(cfg *Config, info component.BuildInfo, traceAgent traceagent.Component, log corelog.Component, sourceProvider source.Provider) (ddprofilingextensiondef.Component, error)
NewExtension creates a new instance of the extension.
func NewFactory ¶
NewFactory creates a factory for Datadog Profiling Extension for use with OCB and OSS Collector
func NewFactoryForAgent ¶
NewFactoryForAgent creates a factory for Datadog Profiling Extension for use with Agent
Types ¶
type Config ¶
type Config struct {
// API contains the configuration for the api for the case of agentless uploads.
// api site is used in non agentless upload setups as well.
// Not setting API section leads to upload to an agent with.
API config.APIConfig `mapstructure:"api"`
ProfilerOptions ProfilerOptions `mapstructure:"profiler_options"`
// Endpoint reports the endpoint used for profiles.
// Default: BuildInfo.Version (e.g. v0.117.0)
Endpoint string `mapstructure:"endpoint"`
}
Config contains the config of the profiler.
type ProfilerOptions ¶
type ProfilerOptions struct {
// Service the profiler will report with.
// Default: BuildInfo.Command (e.g. otel-agent)
Service string `mapstructure:"service"`
// Env the profiler will report with.
// Default: none
Env string `mapstructure:"env"`
// Version the profiler will report with.
// Default: BuildInfo.Version (e.g. v0.117.0)
Version string `mapstructure:"version"`
// Period in seconds the profiler will report with.
// Default: 60s
Period int `mapstructure:"period"`
// ProfileTypes specifies additional profile types to enable.
// supported values are blockprofile, mutexprofile and goroutineprofile.
// By default CPU and Heap profiles are enabled.
ProfileTypes []string `mapstructure:"profile_types"`
}
ProfilerOptions defines settings relevant to the profiler.
Click to show internal directories.
Click to hide internal directories.