logsagentexporter

package module
v0.75.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 11, 2026 License: Apache-2.0 Imports: 30 Imported by: 4

Documentation

Overview

Package logsagentexporter contains a logs exporter which forwards logs to a channel.

Index

Constants

const (
	// TypeStr defines the logsagent exporter type string.
	TypeStr = "logsagent"

	// LogSourceName specifies the Datadog source tag value to be added to logs sent by the logs agent exporter.
	LogSourceName = "otlp_log_ingestion"
)

Variables

This section is empty.

Functions

func NewFactory

func NewFactory(logsAgentChannel chan *message.Message, gatewayUsage otel.GatewayUsage) exp.Factory

NewFactory creates a new logsagentexporter factory. Should only be used in Agent OTLP ingestion pipelines.

func NewFactoryWithType added in v0.65.0

func NewFactoryWithType(logsAgentChannel chan *message.Message, typ component.Type, gatewayUsage otel.GatewayUsage, reporter *inframetadata.Reporter) exp.Factory

NewFactoryWithType creates a new logsagentexporter factory with the given type.

Types

type Config

type Config struct {
	OtelSource    string
	LogSourceName string
	QueueSettings configoptional.Optional[exporterhelper.QueueBatchConfig] `mapstructure:"sending_queue"`

	// HostMetadata defines the host metadata specific configuration
	HostMetadata datadogconfig.HostMetadataConfig `mapstructure:"host_metadata"`

	OrchestratorConfig OrchestratorConfig
}

Config defines configuration for the logs agent exporter.

type Exporter added in v0.56.0

type Exporter struct {
	// contains filtered or unexported fields
}

Exporter defines fields for the logs agent exporter

func NewExporter added in v0.56.0

func NewExporter(
	set component.TelemetrySettings,
	cfg *Config,
	logSource *sources.LogSource,
	logsAgentChannel chan *message.Message,
	attributesTranslator *attributes.Translator,
) (*Exporter, error)

NewExporter initializes a new logs agent exporter with the given parameters

func NewExporterWithGatewayUsage added in v0.65.0

func NewExporterWithGatewayUsage(
	set component.TelemetrySettings,
	cfg *Config,
	logSource *sources.LogSource,
	logsAgentChannel chan *message.Message,
	attributesTranslator *attributes.Translator,
	gatewaysUsage otel.GatewayUsage,
) (*Exporter, error)

NewExporterWithGatewayUsage initializes a new logs agent exporter with the given parameters

func (*Exporter) ConsumeLogs added in v0.56.0

func (e *Exporter) ConsumeLogs(ctx context.Context, ld plog.Logs) (err error)

ConsumeLogs checks the scope of the logs and routes them to the appropriate consumer

type OrchestratorConfig added in v0.74.0

type OrchestratorConfig struct {
	Enabled  bool
	Hostname hostnameinterface.Component
	Key      string
	Site     string
	Endpoint string
}

OrchestratorConfig contains configuration for sending orchestrator data to Datadog.

type ScopeName added in v0.74.0

type ScopeName string

ScopeName represents the name of a scope

var K8sObjectsReceiver ScopeName = "github.com/open-telemetry/opentelemetry-collector-contrib/receiver/k8sobjectsreceiver"

K8sObjectsReceiver is the scope name for the k8sobjectsreceiver

Jump to