agentimpl

package
v0.0.0-...-a2e63a5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2026 License: Apache-2.0 Imports: 25 Imported by: 0

Documentation

Overview

Package agentimpl implements a component for the process agent.

Package agentimpl implements a component for the process agent.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type FlareHelper

type FlareHelper struct {
	Checks []checks.Check
}

FlareHelper is a helper struct to fill the flare with check output.

func NewFlareHelper

func NewFlareHelper(checks []checks.Check) *FlareHelper

NewFlareHelper creates a new FlareHelper to be provided by the process agent component.

func (*FlareHelper) FillFlare

func (fh *FlareHelper) FillFlare(_ context.Context, fb flaretypes.FlareBuilder) error

FillFlare is the callback function for the flare.

type Provides

type Provides struct {
	compdef.Out

	Comp           agent.Component
	StatusProvider statusComponent.InformationProvider
	FlareProvider  flaretypes.Provider
}

func NewComponent

func NewComponent(deps dependencies) (Provides, error)

NewComponent creates a new process agent component.

type StatusProvider

type StatusProvider struct {
	// contains filtered or unexported fields
}

StatusProvider is the type for process component status methods

func NewStatusProvider

func NewStatusProvider(Config config.Component, hostname hostnameinterface.Component) *StatusProvider

NewStatusProvider fetches the status

func (StatusProvider) HTML

func (s StatusProvider) HTML(_ bool, _ io.Writer) error

HTML renders the html output

func (StatusProvider) JSON

func (s StatusProvider) JSON(_ bool, stats map[string]interface{}) error

JSON populates the status map

func (StatusProvider) Name

func (s StatusProvider) Name() string

Name returns the name

func (StatusProvider) Section

func (s StatusProvider) Section() string

Section return the section

func (StatusProvider) Text

func (s StatusProvider) Text(_ bool, buffer io.Writer) error

Text renders the text output

Jump to