submitterimpl

package
v0.0.0-...-a5a9a89 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 20, 2026 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Overview

Package submitterimpl implements a component to submit collected data in the Process Agent to supported Datadog intakes.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Provides

type Provides struct {
	compdef.Out

	RTResponseNotifier <-chan types.RTResponse
	Submitter          submitterComp.Component
}

func NewComponent

func NewComponent(deps dependencies) (Provides, error)

NewComponent creates a new submitter component.

Jump to