Documentation
¶
Overview ¶
Package teeconfig is a tee of two configs that writes to both but reads from only one
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewTeeConfig ¶
func NewTeeConfig(baseline, compare model.BuildableConfig) model.BuildableConfig
NewTeeConfig constructs a new teeConfig
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.