Documentation
¶
Overview ¶
Package erpc holds erpc related files
Index ¶
Constants ¶
const ( // DiscardInodeOp discards an inode DiscardInodeOp = iota + 1 // DiscardPidOp discards a pid (DEPRECATED) DiscardPidOp // ResolveSegmentOp resolves the requested segment (DEPRECATED) ResolveSegmentOp // ResolvePathOp resolves the requested path ResolvePathOp // ResolveParentOp resolves the parent of the provide path key (DEPRECATED) ResolveParentOp // RegisterSpanTLSOP is used for span TLS registration RegisterSpanTLSOP // ExpireInodeDiscarderOp is used to expire an inode discarder ExpireInodeDiscarderOp // ExpirePidDiscarderOp is used to expire a pid discarder ExpirePidDiscarderOp // BumpDiscardersRevisionOp is used to bump the discarders revision (DEPRECATED) BumpDiscardersRevisionOp // GetRingbufUsageOp is used to retrieve the ring buffer usage GetRingbufUsageOp // UserSessionContextOp is used to inject the Kubernetes User context UserSessionContextOp // DiscardPrctlOp is used to discard prctl PR_SET_NAME DiscardPrctlOp // DiscardAuidOp is used to discard AUID DiscardAuidOp // NopEventOp is used to nop an event NopEventOp )
const (
// ERPCDefaultDataSize default size of data of a request
ERPCDefaultDataSize = 256
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ERPC ¶
type ERPC struct {
// contains filtered or unexported fields
}
ERPC defines a krpc object
type Request ¶
type Request struct {
OP uint8
// Data contains the content of the request
// DISCLAIMER: this has to be a byte array, otherwise `unsafe.Pointer(req)` will point to a memory region that
// contains a slice header
Data [ERPCDefaultDataSize]byte
}
Request defines a EPRC request
func NewERPCRequest ¶
NewERPCRequest returns a new eRPC request with a data section of the provided size
Click to show internal directories.
Click to hide internal directories.