types

package module
v0.79.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 2, 2026 License: Apache-2.0 Imports: 1 Imported by: 5

Documentation

Overview

Package types implements the types used by the Tagger for Origin Detection.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type OriginInfo

type OriginInfo struct {
	ContainerIDFromSocket string                        // ContainerIDFromSocket is the origin resolved using Unix Domain Socket.
	LocalData             origindetection.LocalData     // LocalData is the local data list.
	ExternalData          origindetection.ExternalData  // ExternalData is the external data list.
	Cardinality           string                        // Cardinality is the cardinality of the resolved origin.
	ProductOrigin         origindetection.ProductOrigin // ProductOrigin is the product that sent the origin information.
}

OriginInfo contains the Origin Detection information.

Jump to