namespace

package module
v0.78.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2026 License: Apache-2.0 Imports: 3 Imported by: 1

Documentation

Overview

Package namespace provides utility functions for retrieving Kubernetes namespace information

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetMyNamespace

func GetMyNamespace() string

GetMyNamespace returns the namespace our pod is running in

func GetResourcesNamespace

func GetResourcesNamespace() string

GetResourcesNamespace is used to fetch the namespace of the resources used by the Kubernetes check (e.g. Leader Election, Event collection).

Types

This section is empty.

Jump to