Documentation
¶
Overview ¶
Package tagger provides the tagger interface for the Datadog Agent
Package tagger provides the tagger interface for the Datadog Agent
Index ¶
- type Component
- type DualParams
- type Option
- func WithOverrideAuthTokenGetter(getter func(pkgconfigmodel.Reader) (string, error)) Option
- func WithOverrideTLSConfigGetter(getter func() (*tls.Config, error)) Option
- func WithRemoteFilter(filter *types.Filter) Option
- func WithRemoteTarget(remoteTarget func(config.Component) (string, error)) Option
- type OptionalRemoteParams
- type Processor
- type RemoteParams
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Component ¶
type Component interface {
Tag(entityID types.EntityID, cardinality types.TagCardinality) ([]string, error)
GenerateContainerIDFromOriginInfo(originInfo origindetection.OriginInfo) (string, error)
Standard(entityID types.EntityID) ([]string, error)
List() types.TaggerListResponse
GetEntity(entityID types.EntityID) (*types.Entity, error)
// subscriptionID is used for logging and debugging purposes
Subscribe(subscriptionID string, filter *types.Filter) (types.Subscription, error)
GetEntityHash(entityID types.EntityID, cardinality types.TagCardinality) string
AgentTags(cardinality types.TagCardinality) ([]string, error)
// GlobalTags returns the list of static tags that should be applied to all telemetry.
// This is the set of tags that should be attached when host tags are absent.
//
// Cardinality levels:
// - LowCardinality: includes all static tags provided from the config and cluster-level tags
// - OrchestratorCardinality: includes the above and orch-level tags like TaskARN on ECS Fargate
// - HighCardinality: includes the above
// - ChecksConfigCardinality: alias defined via `checks_tag_cardinality` setting an above option
GlobalTags(cardinality types.TagCardinality) ([]string, error)
EnrichTags(tb tagset.TagsAccumulator, originInfo taggertypes.OriginInfo)
}
Component is the component type.
type DualParams ¶
type DualParams struct {
// UseRemote is a function to determine if the remote tagger should be used
UseRemote func(config.Component) bool
}
DualParams provides dual tagger parameters
type Option ¶ added in v0.72.0
type Option = func(*RemoteParams)
Option is a function that modifies the RemoteParams
func WithOverrideAuthTokenGetter ¶ added in v0.72.0
func WithOverrideAuthTokenGetter(getter func(pkgconfigmodel.Reader) (string, error)) Option
WithOverrideAuthTokenGetter sets the OverrideAuthTokenGetter function
func WithOverrideTLSConfigGetter ¶ added in v0.72.0
WithOverrideTLSConfigGetter sets the OverrideTLSConfigGetter function
func WithRemoteFilter ¶ added in v0.72.0
WithRemoteFilter sets the RemoteFilter function
type OptionalRemoteParams ¶ added in v0.71.0
type OptionalRemoteParams struct {
// Disable opts out of the remote tagger in favor of the noop tagger
Disable func(config.Component) bool
}
OptionalRemoteParams provides the optional remote tagger parameters
type RemoteParams ¶
type RemoteParams struct {
// RemoteFilter is the filter to apply to the remote tagger when streaming tag events
RemoteFilter *types.Filter
// RemoteTarget function return the target in which the remote tagger will connect
// If it returns an error we stop the application
RemoteTarget func(config.Component) (string, error)
// OverrideTLSConfigGetter allows to override the TLS configuration used by the remote tagger
// This should be used only for Cluster Agent x CLC communication
OverrideTLSConfigGetter func() (*tls.Config, error)
// OverrideAuthTokenGetter allows to override the auth token used by the remote tagger
// This should be used only for Cluster Agent x CLC communication
OverrideAuthTokenGetter func(pkgconfigmodel.Reader) (string, error)
}
RemoteParams provides remote tagger parameters
func NewRemoteParams ¶ added in v0.72.0
func NewRemoteParams(opts ...Option) RemoteParams
NewRemoteParams creates a new RemoteParams with the default values