Documentation
¶
Overview ¶
Package subscriber implements the functionality needed to subscribe to events generated by the Tagger component.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Subscriber ¶
type Subscriber struct {
// contains filtered or unexported fields
}
Subscriber describes a component that subscribes to the tagger Subscriber implements types.Subscription
func (*Subscriber) EventsChan ¶
func (s *Subscriber) EventsChan() chan []types.EntityEvent
EventsChan implements #types.Subscription.EventsChan
func (*Subscriber) Unsubscribe ¶
func (s *Subscriber) Unsubscribe()
Unsubscribe implements #types.Subscription.Unsubscribe
type SubscriptionManager ¶
type SubscriptionManager interface {
Subscribe(id string, filter *types.Filter, events []types.EntityEvent) (types.Subscription, error)
Unsubscribe(subscriptionID string)
Notify(events []types.EntityEvent)
}
SubscriptionManager allows processes to subscribe to entity events generated from a tagger.
func NewSubscriptionManager ¶
func NewSubscriptionManager(telemetryStore *telemetry.Store) SubscriptionManager
NewSubscriptionManager creates and returns a new subscription manager
Click to show internal directories.
Click to hide internal directories.