Documentation
¶
Overview ¶
Package utils defines several helpers used by the Tagger component.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ComputeTagsHash ¶
ComputeTagsHash returns a hash of the supplied tags.
func ConcatenateStringTags ¶
ConcatenateStringTags adds string tags to existing tag array
func ConcatenateTags ¶
ConcatenateTags is a fast way to concatenate multiple tag arrays in a single one.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.