Documentation
¶
Overview ¶
Package hostimpl implements a component to generate the 'host' metadata payload (also known as "v5").
Package hostimpl implements a component to generate the 'host' metadata payload (also known as "v5").
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Payload ¶
type Payload struct {
utils.CommonPayload
utils.Payload
ResourcesPayload interface{} `json:"resources,omitempty"`
GohaiPayload string `json:"gohai"`
}
Payload handles the JSON unmarshalling of the metadata payload
func (*Payload) MarshalJSON ¶
MarshalJSON serialization a Payload to JSON
type Provides ¶
type Provides struct {
compdef.Out
Comp hostComp.Component
MetadataProvider runnerdef.Provider
FlareProvider flaretypes.Provider
StatusHeaderProvider status.HeaderInformationProvider
Endpoint api.AgentEndpointProvider
GohaiEndpoint api.AgentEndpointProvider
}
Provides defines the output of the host metadata component
func NewComponent ¶
NewComponent creates a new host metadata component
type Requires ¶
type Requires struct {
compdef.In
Log log.Component
Config config.Component
Resources resources.Component
Serializer serializer.MetricSerializer
Hostname hostnameinterface.Component
}
Requires defines the dependencies for the host metadata component
type StatusProvider ¶
type StatusProvider struct {
Config config.Component
Hostname hostnameinterface.Component
}
StatusProvider implements the status provider interface
func (StatusProvider) HTML ¶
func (p StatusProvider) HTML(_ bool, buffer io.Writer) error
HTML renders the html output
Click to show internal directories.
Click to hide internal directories.