Documentation
¶
Overview ¶
Package serverimpl implements the netflow server component.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Provider ¶
type Provider struct {
// contains filtered or unexported fields
}
Provider provides the functionality to populate the status output
type Provides ¶
type Provides struct {
compdef.Out
Comp server.Component
StatusProvider status.InformationProvider
}
Provides defines what the netflow server component provides.
func NewComponent ¶
NewComponent configures a netflow server.
type Requires ¶
type Requires struct {
compdef.In
Lc compdef.Lifecycle
Config nfconfig.Component
Logger log.Component
Demultiplexer demultiplexer.Component
Forwarder forwarder.Component
Hostname hostname.Component
RDNSQuerier rdnsquerier.Component
}
Requires defines the dependencies for the netflow server component.
type Server ¶
type Server struct {
Addr string
FlowAgg *flowaggregator.FlowAggregator
// contains filtered or unexported fields
}
Server manages netflow listeners.
Click to show internal directories.
Click to hide internal directories.