Documentation
¶
Overview ¶
Package agentimpl implements a component for the process agent.
Package agentimpl implements a component for the process agent.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FlareHelper ¶
FlareHelper is a helper struct to fill the flare with check output.
func NewFlareHelper ¶
func NewFlareHelper(checks []checks.Check) *FlareHelper
NewFlareHelper creates a new FlareHelper to be provided by the process agent component.
func (*FlareHelper) FillFlare ¶
func (fh *FlareHelper) FillFlare(_ context.Context, fb flaretypes.FlareBuilder) error
FillFlare is the callback function for the flare.
type Provides ¶
type Provides struct {
compdef.Out
Comp agent.Component
StatusProvider statusComponent.InformationProvider
FlareProvider flaretypes.Provider
}
func NewComponent ¶
NewComponent creates a new process agent component.
type StatusProvider ¶
type StatusProvider struct {
// contains filtered or unexported fields
}
StatusProvider is the type for process component status methods
func NewStatusProvider ¶
func NewStatusProvider(Config config.Component, hostname hostnameinterface.Component) *StatusProvider
NewStatusProvider fetches the status
func (StatusProvider) HTML ¶
func (s StatusProvider) HTML(_ bool, _ io.Writer) error
HTML renders the html output
Click to show internal directories.
Click to hide internal directories.