Documentation
¶
Overview ¶
Package nodetreemodel defines a model for the config using a tree of nodes
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrNotFound = errors.New("not found")
ErrNotFound is an error for when a key is not found
Functions ¶
func NewNodeTreeConfig ¶ added in v0.66.0
func NewNodeTreeConfig(name string, envPrefix string, envKeyReplacer *strings.Replacer) model.BuildableConfig
NewNodeTreeConfig returns a new Config object.
Types ¶
type Node ¶ added in v0.60.0
type Node interface {
IsLeafNode() bool
IsInnerNode() bool
Get() interface{}
ChildrenKeys() []string
}
Node is a inner or leaf node in the config tree
type NodeTreeConfig ¶ added in v0.60.0
NodeTreeConfig is an interface that gives access to nodes
Click to show internal directories.
Click to hide internal directories.