Documentation
¶
Overview ¶
Package kernelbugs provides runtime detection for kernel bugs effecting system-probe
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HasTasksRCUExitLockSymbol ¶
HasTasksRCUExitLockSymbol returns true if the tasks_rcu_exit_srcu symbol is found in the kernel symbols. The tasks_rcu_exit_srcu lock might cause a deadlock when removing fentry trampolines. This was fixed by https://github.com/torvalds/linux/commit/1612160b91272f5b1596f499584d6064bf5be794
func HasUretprobeSyscallSeccompBug ¶
HasUretprobeSyscallSeccompBug returns false if no bpf is available
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.