Documentation
¶
Overview ¶
Package types implements the types used by the Tagger for Origin Detection.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type OriginInfo ¶
type OriginInfo struct {
ContainerIDFromSocket string // ContainerIDFromSocket is the origin resolved using Unix Domain Socket.
LocalData origindetection.LocalData // LocalData is the local data list.
ExternalData origindetection.ExternalData // ExternalData is the external data list.
Cardinality string // Cardinality is the cardinality of the resolved origin.
ProductOrigin origindetection.ProductOrigin // ProductOrigin is the product that sent the origin information.
}
OriginInfo contains the Origin Detection information.
Click to show internal directories.
Click to hide internal directories.