Documentation
¶
Overview ¶
Package namespace provides utility functions for retrieving Kubernetes namespace information
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetMyNamespace ¶
func GetMyNamespace() string
GetMyNamespace returns the namespace our pod is running in
func GetResourcesNamespace ¶
func GetResourcesNamespace() string
GetResourcesNamespace is used to fetch the namespace of the resources used by the Kubernetes check (e.g. Leader Election, Event collection).
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.